Class: Aws::BCMRecommendedActions::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::BCMRecommendedActions::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-bcmrecommendedactions/client.rb
Overview
An API client for BCMRecommendedActions. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::BCMRecommendedActions::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#list_recommended_actions(params = {}) ⇒ Types::ListRecommendedActionsResponse
Returns a list of recommended actions that match the filter criteria.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
480 481 482 |
# File 'lib/aws-sdk-bcmrecommendedactions/client.rb', line 480 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
576 577 578 |
# File 'lib/aws-sdk-bcmrecommendedactions/client.rb', line 576 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
579 580 581 |
# File 'lib/aws-sdk-bcmrecommendedactions/client.rb', line 579 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 |
# File 'lib/aws-sdk-bcmrecommendedactions/client.rb', line 549 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::BCMRecommendedActions') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-bcmrecommendedactions' context[:gem_version] = '1.11.0' Seahorse::Client::Request.new(handlers, context) end |
#list_recommended_actions(params = {}) ⇒ Types::ListRecommendedActionsResponse
Returns a list of recommended actions that match the filter criteria.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
540 541 542 543 |
# File 'lib/aws-sdk-bcmrecommendedactions/client.rb', line 540 def list_recommended_actions(params = {}, = {}) req = build_request(:list_recommended_actions, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
569 570 571 |
# File 'lib/aws-sdk-bcmrecommendedactions/client.rb', line 569 def waiter_names [] end |